@@ -18,7 +18,6 @@ import mock
 
 
 class Test__LocalStack(unittest.TestCase):
-
     @staticmethod
     def _get_target_class():
         from google.cloud._helpers import _LocalStack
@@ -47,7 +46,6 @@ class Test__LocalStack(unittest.TestCase):
 
 
 class Test__UTC(unittest.TestCase):
-
     @staticmethod
     def _get_target_class():
         from google.cloud._helpers import _UTC
@@ -77,8 +75,7 @@ class Test__UTC(unittest.TestCase):
     def test_fromutc(self):
         import datetime
 
-        naive_epoch = datetime.datetime(
-            1970, 1, 1, 0, 0, 1, tzinfo=None)
+        naive_epoch = datetime.datetime(1970, 1, 1, 0, 0, 1, tzinfo=None)
         self.assertIsNone(naive_epoch.tzinfo)
         tz = self._make_one()
         epoch = tz.fromutc(naive_epoch)
@@ -88,14 +85,13 @@ class Test__UTC(unittest.TestCase):
         import datetime
 
         tz = self._make_one()
-        epoch_with_tz = datetime.datetime(
-            1970, 1, 1, 0, 0, 1, tzinfo=tz)
+        epoch_with_tz = datetime.datetime(1970, 1, 1, 0, 0, 1, tzinfo=tz)
         epoch = tz.fromutc(epoch_with_tz)
         self.assertEqual(epoch.tzinfo, tz)
 
     def test_tzname(self):
         tz = self._make_one()
-        self.assertEqual(tz.tzname(None), 'UTC')
+        self.assertEqual(tz.tzname(None), "UTC")
 
     def test_utcoffset(self):
         import datetime
@@ -105,59 +101,56 @@ class Test__UTC(unittest.TestCase):
 
     def test___repr__(self):
         tz = self._make_one()
-        self.assertEqual(repr(tz), '<UTC>')
+        self.assertEqual(repr(tz), "<UTC>")
 
     def test___str__(self):
         tz = self._make_one()
-        self.assertEqual(str(tz), 'UTC')
+        self.assertEqual(str(tz), "UTC")
 
 
 class Test__ensure_tuple_or_list(unittest.TestCase):
-
     def _call_fut(self, arg_name, tuple_or_list):
         from google.cloud._helpers import _ensure_tuple_or_list
 
         return _ensure_tuple_or_list(arg_name, tuple_or_list)
 
     def test_valid_tuple(self):
-        valid_tuple_or_list = ('a', 'b', 'c', 'd')
-        result = self._call_fut('ARGNAME', valid_tuple_or_list)
-        self.assertEqual(result, ['a', 'b', 'c', 'd'])
+        valid_tuple_or_list = ("a", "b", "c", "d")
+        result = self._call_fut("ARGNAME", valid_tuple_or_list)
+        self.assertEqual(result, ["a", "b", "c", "d"])
 
     def test_valid_list(self):
-        valid_tuple_or_list = ['a', 'b', 'c', 'd']
-        result = self._call_fut('ARGNAME', valid_tuple_or_list)
+        valid_tuple_or_list = ["a", "b", "c", "d"]
+        result = self._call_fut("ARGNAME", valid_tuple_or_list)
         self.assertEqual(result, valid_tuple_or_list)
 
     def test_invalid(self):
         invalid_tuple_or_list = object()
         with self.assertRaises(TypeError):
-            self._call_fut('ARGNAME', invalid_tuple_or_list)
+            self._call_fut("ARGNAME", invalid_tuple_or_list)
 
     def test_invalid_iterable(self):
-        invalid_tuple_or_list = 'FOO'
+        invalid_tuple_or_list = "FOO"
         with self.assertRaises(TypeError):
-            self._call_fut('ARGNAME', invalid_tuple_or_list)
+            self._call_fut("ARGNAME", invalid_tuple_or_list)
 
 
 class Test__determine_default_project(unittest.TestCase):
-
     def _call_fut(self, project=None):
         from google.cloud._helpers import _determine_default_project
 
         return _determine_default_project(project=project)
 
     def test_it(self):
-        with mock.patch('google.auth.default', autospec=True) as default:
-            default.return_value = (
-                mock.sentinel.credentials, mock.sentinel.project)
+        with mock.patch("google.auth.default", autospec=True) as default:
+            default.return_value = (mock.sentinel.credentials, mock.sentinel.project)
             project = self._call_fut()
 
         self.assertEqual(project, mock.sentinel.project)
         default.assert_called_once_with()
 
     def test_explicit(self):
-        with mock.patch('google.auth.default', autospec=True) as default:
+        with mock.patch("google.auth.default", autospec=True) as default:
             project = self._call_fut(mock.sentinel.project)
 
         self.assertEqual(project, mock.sentinel.project)
@@ -165,7 +158,6 @@ class Test__determine_default_project(unittest.TestCase):
 
 
 class Test__millis(unittest.TestCase):
-
     def _call_fut(self, value):
         from google.cloud._helpers import _millis
 
@@ -180,7 +172,6 @@ class Test__millis(unittest.TestCase):
 
 
 class Test__microseconds_from_datetime(unittest.TestCase):
-
     def _call_fut(self, value):
         from google.cloud._helpers import _microseconds_from_datetime
 
@@ -190,15 +181,14 @@ class Test__microseconds_from_datetime(unittest.TestCase):
         import datetime
 
         microseconds = 314159
-        timestamp = datetime.datetime(1970, 1, 1, hour=0,
-                                      minute=0, second=0,
-                                      microsecond=microseconds)
+        timestamp = datetime.datetime(
+            1970, 1, 1, hour=0, minute=0, second=0, microsecond=microseconds
+        )
         result = self._call_fut(timestamp)
         self.assertEqual(result, microseconds)
 
 
 class Test__millis_from_datetime(unittest.TestCase):
-
     def _call_fut(self, value):
         from google.cloud._helpers import _millis_from_datetime
 
@@ -227,7 +217,7 @@ class Test__millis_from_datetime(unittest.TestCase):
         from google.cloud._helpers import _microseconds_from_datetime
 
         class CET(_UTC):
-            _tzname = 'CET'
+            _tzname = "CET"
             _utcoffset = datetime.timedelta(hours=-1)
 
         zone = CET()
@@ -254,7 +244,6 @@ class Test__millis_from_datetime(unittest.TestCase):
 
 
 class Test__datetime_from_microseconds(unittest.TestCase):
-
     def _call_fut(self, value):
         from google.cloud._helpers import _datetime_from_microseconds
 
@@ -265,14 +254,12 @@ class Test__datetime_from_microseconds(unittest.TestCase):
         from google.cloud._helpers import UTC
         from google.cloud._helpers import _microseconds_from_datetime
 
-        NOW = datetime.datetime(2015, 7, 29, 17, 45, 21, 123456,
-                                tzinfo=UTC)
+        NOW = datetime.datetime(2015, 7, 29, 17, 45, 21, 123456, tzinfo=UTC)
         NOW_MICROS = _microseconds_from_datetime(NOW)
         self.assertEqual(self._call_fut(NOW_MICROS), NOW)
 
 
 class Test___date_from_iso8601_date(unittest.TestCase):
-
     def _call_fut(self, value):
         from google.cloud._helpers import _date_from_iso8601_date
 
@@ -286,7 +273,6 @@ class Test___date_from_iso8601_date(unittest.TestCase):
 
 
 class Test___time_from_iso8601_time_naive(unittest.TestCase):
-
     def _call_fut(self, value):
         from google.cloud._helpers import _time_from_iso8601_time_naive
 
@@ -298,9 +284,18 @@ class Test___time_from_iso8601_time_naive(unittest.TestCase):
         WHEN = datetime.time(12, 9, 42)
         self.assertEqual(self._call_fut(("12:09:42")), WHEN)
 
+    def test_w_microseconds(self):
+        import datetime
+
+        WHEN = datetime.time(12, 9, 42, 123456)
+        self.assertEqual(self._call_fut(("12:09:42.123456")), WHEN)
+
+    def test_w_millis_fail(self):
+        with self.assertRaises(ValueError):
+            self._call_fut("12:09:42.123")
+
 
 class Test__rfc3339_to_datetime(unittest.TestCase):
-
     def _call_fut(self, dt_str):
         from google.cloud._helpers import _rfc3339_to_datetime
 
@@ -315,8 +310,15 @@ class Test__rfc3339_to_datetime(unittest.TestCase):
         seconds = 32
         micros = 123456789
 
-        dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%06dBOGUS' % (
-            year, month, day, hour, minute, seconds, micros)
+        dt_str = "%d-%02d-%02dT%02d:%02d:%02d.%06dBOGUS" % (
+            year,
+            month,
+            day,
+            hour,
+            minute,
+            seconds,
+            micros,
+        )
         with self.assertRaises(ValueError):
             self._call_fut(dt_str)
 
@@ -332,11 +334,19 @@ class Test__rfc3339_to_datetime(unittest.TestCase):
         seconds = 32
         micros = 123456
 
-        dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%06dZ' % (
-            year, month, day, hour, minute, seconds, micros)
+        dt_str = "%d-%02d-%02dT%02d:%02d:%02d.%06dZ" % (
+            year,
+            month,
+            day,
+            hour,
+            minute,
+            seconds,
+            micros,
+        )
         result = self._call_fut(dt_str)
         expected_result = datetime.datetime(
-            year, month, day, hour, minute, seconds, micros, UTC)
+            year, month, day, hour, minute, seconds, micros, UTC
+        )
         self.assertEqual(result, expected_result)
 
     def test_w_naonseconds(self):
@@ -348,14 +358,20 @@ class Test__rfc3339_to_datetime(unittest.TestCase):
         seconds = 32
         nanos = 123456789
 
-        dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%09dZ' % (
-            year, month, day, hour, minute, seconds, nanos)
+        dt_str = "%d-%02d-%02dT%02d:%02d:%02d.%09dZ" % (
+            year,
+            month,
+            day,
+            hour,
+            minute,
+            seconds,
+            nanos,
+        )
         with self.assertRaises(ValueError):
             self._call_fut(dt_str)
 
 
 class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
-
     def _call_fut(self, dt_str):
         from google.cloud._helpers import _rfc3339_nanos_to_datetime
 
@@ -370,8 +386,15 @@ class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
         seconds = 32
         micros = 123456789
 
-        dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%06dBOGUS' % (
-            year, month, day, hour, minute, seconds, micros)
+        dt_str = "%d-%02d-%02dT%02d:%02d:%02d.%06dBOGUS" % (
+            year,
+            month,
+            day,
+            hour,
+            minute,
+            seconds,
+            micros,
+        )
         with self.assertRaises(ValueError):
             self._call_fut(dt_str)
 
@@ -386,22 +409,30 @@ class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
         minute = 44
         seconds = 32
         truncateds_and_micros = [
-            ('12345678', 123456),
-            ('1234567', 123456),
-            ('123456', 123456),
-            ('12345', 123450),
-            ('1234', 123400),
-            ('123', 123000),
-            ('12', 120000),
-            ('1', 100000),
+            ("12345678", 123456),
+            ("1234567", 123456),
+            ("123456", 123456),
+            ("12345", 123450),
+            ("1234", 123400),
+            ("123", 123000),
+            ("12", 120000),
+            ("1", 100000),
         ]
 
         for truncated, micros in truncateds_and_micros:
-            dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%sZ' % (
-                year, month, day, hour, minute, seconds, truncated)
+            dt_str = "%d-%02d-%02dT%02d:%02d:%02d.%sZ" % (
+                year,
+                month,
+                day,
+                hour,
+                minute,
+                seconds,
+                truncated,
+            )
             result = self._call_fut(dt_str)
             expected_result = datetime.datetime(
-                year, month, day, hour, minute, seconds, micros, UTC)
+                year, month, day, hour, minute, seconds, micros, UTC
+            )
             self.assertEqual(result, expected_result)
 
     def test_without_nanos(self):
@@ -415,11 +446,18 @@ class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
         minute = 12
         seconds = 12
 
-        dt_str = '%d-%02d-%02dT%02d:%02d:%02dZ' % (
-            year, month, day, hour, minute, seconds)
+        dt_str = "%d-%02d-%02dT%02d:%02d:%02dZ" % (
+            year,
+            month,
+            day,
+            hour,
+            minute,
+            seconds,
+        )
         result = self._call_fut(dt_str)
         expected_result = datetime.datetime(
-            year, month, day, hour, minute, seconds, 0, UTC)
+            year, month, day, hour, minute, seconds, 0, UTC
+        )
         self.assertEqual(result, expected_result)
 
     def test_w_naonseconds(self):
@@ -435,16 +473,23 @@ class Test__rfc3339_nanos_to_datetime(unittest.TestCase):
         nanos = 123456789
         micros = nanos // 1000
 
-        dt_str = '%d-%02d-%02dT%02d:%02d:%02d.%09dZ' % (
-            year, month, day, hour, minute, seconds, nanos)
+        dt_str = "%d-%02d-%02dT%02d:%02d:%02d.%09dZ" % (
+            year,
+            month,
+            day,
+            hour,
+            minute,
+            seconds,
+            nanos,
+        )
         result = self._call_fut(dt_str)
         expected_result = datetime.datetime(
-            year, month, day, hour, minute, seconds, micros, UTC)
+            year, month, day, hour, minute, seconds, micros, UTC
+        )
         self.assertEqual(result, expected_result)
 
 
 class Test__datetime_to_rfc3339(unittest.TestCase):
-
     def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import _datetime_to_rfc3339
 
@@ -455,7 +500,7 @@ class Test__datetime_to_rfc3339(unittest.TestCase):
         from google.cloud._helpers import _UTC
 
         class CET(_UTC):
-            _tzname = 'CET'
+            _tzname = "CET"
             _utcoffset = offset
 
         return CET()
@@ -466,7 +511,7 @@ class Test__datetime_to_rfc3339(unittest.TestCase):
 
         TIMESTAMP = datetime.datetime(2016, 4, 5, 13, 30, 0, tzinfo=UTC)
         result = self._call_fut(TIMESTAMP, ignore_zone=False)
-        self.assertEqual(result, '2016-04-05T13:30:00.000000Z')
+        self.assertEqual(result, "2016-04-05T13:30:00.000000Z")
 
     def test_w_non_utc_datetime(self):
         import datetime
@@ -474,7 +519,7 @@ class Test__datetime_to_rfc3339(unittest.TestCase):
         zone = self._make_timezone(offset=datetime.timedelta(hours=-1))
         TIMESTAMP = datetime.datetime(2016, 4, 5, 13, 30, 0, tzinfo=zone)
         result = self._call_fut(TIMESTAMP, ignore_zone=False)
-        self.assertEqual(result, '2016-04-05T14:30:00.000000Z')
+        self.assertEqual(result, "2016-04-05T14:30:00.000000Z")
 
     def test_w_non_utc_datetime_and_ignore_zone(self):
         import datetime
@@ -482,38 +527,36 @@ class Test__datetime_to_rfc3339(unittest.TestCase):
         zone = self._make_timezone(offset=datetime.timedelta(hours=-1))
         TIMESTAMP = datetime.datetime(2016, 4, 5, 13, 30, 0, tzinfo=zone)
         result = self._call_fut(TIMESTAMP)
-        self.assertEqual(result, '2016-04-05T13:30:00.000000Z')
+        self.assertEqual(result, "2016-04-05T13:30:00.000000Z")
 
     def test_w_naive_datetime(self):
         import datetime
 
         TIMESTAMP = datetime.datetime(2016, 4, 5, 13, 30, 0)
         result = self._call_fut(TIMESTAMP)
-        self.assertEqual(result, '2016-04-05T13:30:00.000000Z')
+        self.assertEqual(result, "2016-04-05T13:30:00.000000Z")
 
 
 class Test__to_bytes(unittest.TestCase):
-
     def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import _to_bytes
 
         return _to_bytes(*args, **kwargs)
 
     def test_with_bytes(self):
-        value = b'bytes-val'
+        value = b"bytes-val"
         self.assertEqual(self._call_fut(value), value)
 
     def test_with_unicode(self):
-        value = u'string-val'
-        encoded_value = b'string-val'
+        value = u"string-val"
+        encoded_value = b"string-val"
         self.assertEqual(self._call_fut(value), encoded_value)
 
     def test_unicode_non_ascii(self):
-        value = u'\u2013'  # Long hyphen
-        encoded_value = b'\xe2\x80\x93'
+        value = u"\u2013"  # Long hyphen
+        encoded_value = b"\xe2\x80\x93"
         self.assertRaises(UnicodeEncodeError, self._call_fut, value)
-        self.assertEqual(self._call_fut(value, encoding='utf-8'),
-                         encoded_value)
+        self.assertEqual(self._call_fut(value, encoding="utf-8"), encoded_value)
 
     def test_with_nonstring_type(self):
         value = object()
@@ -521,20 +564,19 @@ class Test__to_bytes(unittest.TestCase):
 
 
 class Test__bytes_to_unicode(unittest.TestCase):
-
     def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import _bytes_to_unicode
 
         return _bytes_to_unicode(*args, **kwargs)
 
     def test_with_bytes(self):
-        value = b'bytes-val'
-        encoded_value = 'bytes-val'
+        value = b"bytes-val"
+        encoded_value = "bytes-val"
         self.assertEqual(self._call_fut(value), encoded_value)
 
     def test_with_unicode(self):
-        value = u'string-val'
-        encoded_value = 'string-val'
+        value = u"string-val"
+        encoded_value = "string-val"
         self.assertEqual(self._call_fut(value), encoded_value)
 
     def test_with_nonstring_type(self):
@@ -543,7 +585,6 @@ class Test__bytes_to_unicode(unittest.TestCase):
 
 
 class Test__pb_timestamp_to_datetime(unittest.TestCase):
-
     def _call_fut(self, timestamp):
         from google.cloud._helpers import _pb_timestamp_to_datetime
 
@@ -555,9 +596,16 @@ class Test__pb_timestamp_to_datetime(unittest.TestCase):
         from google.cloud._helpers import UTC
 
         # Epoch is midnight on January 1, 1970 ...
-        dt_stamp = datetime.datetime(1970, month=1, day=1, hour=0,
-                                     minute=1, second=1, microsecond=1234,
-                                     tzinfo=UTC)
+        dt_stamp = datetime.datetime(
+            1970,
+            month=1,
+            day=1,
+            hour=0,
+            minute=1,
+            second=1,
+            microsecond=1234,
+            tzinfo=UTC,
+        )
         # ... so 1 minute and 1 second after is 61 seconds and 1234
         # microseconds is 1234000 nanoseconds.
         timestamp = Timestamp(seconds=61, nanos=1234000)
@@ -565,7 +613,6 @@ class Test__pb_timestamp_to_datetime(unittest.TestCase):
 
 
 class Test__from_any_pb(unittest.TestCase):
-
     def _call_fut(self, pb_type, any_pb):
         from google.cloud._helpers import _from_any_pb
 
@@ -581,7 +628,7 @@ class Test__from_any_pb(unittest.TestCase):
         out_message = self._call_fut(date_pb2.Date, in_message_any)
         self.assertEqual(in_message, out_message)
 
-    def test_failure(self, ):
+    def test_failure(self,):
         from google.protobuf import any_pb2
         from google.type import date_pb2
         from google.type import timeofday_pb2
@@ -594,7 +641,6 @@ class Test__from_any_pb(unittest.TestCase):
 
 
 class Test__pb_timestamp_to_rfc3339(unittest.TestCase):
-
     def _call_fut(self, timestamp):
         from google.cloud._helpers import _pb_timestamp_to_rfc3339
 
@@ -607,12 +653,10 @@ class Test__pb_timestamp_to_rfc3339(unittest.TestCase):
         # ... so 1 minute and 1 second after is 61 seconds and 1234
         # microseconds is 1234000 nanoseconds.
         timestamp = Timestamp(seconds=61, nanos=1234000)
-        self.assertEqual(self._call_fut(timestamp),
-                         '1970-01-01T00:01:01.001234Z')
+        self.assertEqual(self._call_fut(timestamp), "1970-01-01T00:01:01.001234Z")
 
 
 class Test__datetime_to_pb_timestamp(unittest.TestCase):
-
     def _call_fut(self, when):
         from google.cloud._helpers import _datetime_to_pb_timestamp
 
@@ -624,9 +668,16 @@ class Test__datetime_to_pb_timestamp(unittest.TestCase):
         from google.cloud._helpers import UTC
 
         # Epoch is midnight on January 1, 1970 ...
-        dt_stamp = datetime.datetime(1970, month=1, day=1, hour=0,
-                                     minute=1, second=1, microsecond=1234,
-                                     tzinfo=UTC)
+        dt_stamp = datetime.datetime(
+            1970,
+            month=1,
+            day=1,
+            hour=0,
+            minute=1,
+            second=1,
+            microsecond=1234,
+            tzinfo=UTC,
+        )
         # ... so 1 minute and 1 second after is 61 seconds and 1234
         # microseconds is 1234000 nanoseconds.
         timestamp = Timestamp(seconds=61, nanos=1234000)
@@ -634,7 +685,6 @@ class Test__datetime_to_pb_timestamp(unittest.TestCase):
 
 
 class Test__timedelta_to_duration_pb(unittest.TestCase):
-
     def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import _timedelta_to_duration_pb
 
@@ -645,8 +695,7 @@ class Test__timedelta_to_duration_pb(unittest.TestCase):
         from google.protobuf import duration_pb2
 
         seconds = microseconds = 1
-        timedelta_val = datetime.timedelta(seconds=seconds,
-                                           microseconds=microseconds)
+        timedelta_val = datetime.timedelta(seconds=seconds, microseconds=microseconds)
         result = self._call_fut(timedelta_val)
         self.assertIsInstance(result, duration_pb2.Duration)
         self.assertEqual(result.seconds, seconds)
@@ -658,12 +707,11 @@ class Test__timedelta_to_duration_pb(unittest.TestCase):
 
         seconds = 1
         microseconds = -5
-        timedelta_val = datetime.timedelta(seconds=seconds,
-                                           microseconds=microseconds)
+        timedelta_val = datetime.timedelta(seconds=seconds, microseconds=microseconds)
         result = self._call_fut(timedelta_val)
         self.assertIsInstance(result, duration_pb2.Duration)
         self.assertEqual(result.seconds, seconds - 1)
-        self.assertEqual(result.nanos, 10**9 + 1000 * microseconds)
+        self.assertEqual(result.nanos, 10 ** 9 + 1000 * microseconds)
 
     def test_with_negative_seconds(self):
         import datetime
@@ -671,16 +719,14 @@ class Test__timedelta_to_duration_pb(unittest.TestCase):
 
         seconds = -1
         microseconds = 5
-        timedelta_val = datetime.timedelta(seconds=seconds,
-                                           microseconds=microseconds)
+        timedelta_val = datetime.timedelta(seconds=seconds, microseconds=microseconds)
         result = self._call_fut(timedelta_val)
         self.assertIsInstance(result, duration_pb2.Duration)
         self.assertEqual(result.seconds, seconds + 1)
-        self.assertEqual(result.nanos, -(10**9 - 1000 * microseconds))
+        self.assertEqual(result.nanos, -(10 ** 9 - 1000 * microseconds))
 
 
 class Test__duration_pb_to_timedelta(unittest.TestCase):
-
     def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import _duration_pb_to_timedelta
 
@@ -691,10 +737,8 @@ class Test__duration_pb_to_timedelta(unittest.TestCase):
         from google.protobuf import duration_pb2
 
         seconds = microseconds = 1
-        duration_pb = duration_pb2.Duration(seconds=seconds,
-                                            nanos=1000 * microseconds)
-        timedelta_val = datetime.timedelta(seconds=seconds,
-                                           microseconds=microseconds)
+        duration_pb = duration_pb2.Duration(seconds=seconds, nanos=1000 * microseconds)
+        timedelta_val = datetime.timedelta(seconds=seconds, microseconds=microseconds)
         result = self._call_fut(duration_pb)
         self.assertIsInstance(result, datetime.timedelta)
         self.assertEqual(result, timedelta_val)
@@ -702,9 +746,9 @@ class Test__duration_pb_to_timedelta(unittest.TestCase):
 
 class Test__name_from_project_path(unittest.TestCase):
 
-    PROJECT = 'PROJECT'
-    THING_NAME = 'THING_NAME'
-    TEMPLATE = r'projects/(?P<project>\w+)/things/(?P<name>\w+)'
+    PROJECT = "PROJECT"
+    THING_NAME = "THING_NAME"
+    TEMPLATE = r"projects/(?P<project>\w+)/things/(?P<name>\w+)"
 
     def _call_fut(self, path, project, template):
         from google.cloud._helpers import _name_from_project_path
@@ -712,19 +756,19 @@ class Test__name_from_project_path(unittest.TestCase):
         return _name_from_project_path(path, project, template)
 
     def test_w_invalid_path_length(self):
-        PATH = 'projects/foo'
+        PATH = "projects/foo"
         with self.assertRaises(ValueError):
             self._call_fut(PATH, None, self.TEMPLATE)
 
     def test_w_invalid_path_segments(self):
-        PATH = 'foo/%s/bar/%s' % (self.PROJECT, self.THING_NAME)
+        PATH = "foo/%s/bar/%s" % (self.PROJECT, self.THING_NAME)
         with self.assertRaises(ValueError):
             self._call_fut(PATH, self.PROJECT, self.TEMPLATE)
 
     def test_w_mismatched_project(self):
-        PROJECT1 = 'PROJECT1'
-        PROJECT2 = 'PROJECT2'
-        PATH = 'projects/%s/things/%s' % (PROJECT1, self.THING_NAME)
+        PROJECT1 = "PROJECT1"
+        PROJECT2 = "PROJECT2"
+        PATH = "projects/%s/things/%s" % (PROJECT1, self.THING_NAME)
         with self.assertRaises(ValueError):
             self._call_fut(PATH, PROJECT2, self.TEMPLATE)
 
@@ -732,20 +776,19 @@ class Test__name_from_project_path(unittest.TestCase):
         import re
 
         template = re.compile(self.TEMPLATE)
-        PATH = 'projects/%s/things/%s' % (self.PROJECT, self.THING_NAME)
+        PATH = "projects/%s/things/%s" % (self.PROJECT, self.THING_NAME)
         name = self._call_fut(PATH, self.PROJECT, template)
         self.assertEqual(name, self.THING_NAME)
 
     def test_w_project_passed_as_none(self):
-        PROJECT1 = 'PROJECT1'
-        PATH = 'projects/%s/things/%s' % (PROJECT1, self.THING_NAME)
+        PROJECT1 = "PROJECT1"
+        PATH = "projects/%s/things/%s" % (PROJECT1, self.THING_NAME)
         self._call_fut(PATH, None, self.TEMPLATE)
         name = self._call_fut(PATH, None, self.TEMPLATE)
         self.assertEqual(name, self.THING_NAME)
 
 
 class Test_make_secure_channel(unittest.TestCase):
-
     def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import make_secure_channel
 
@@ -755,54 +798,51 @@ class Test_make_secure_channel(unittest.TestCase):
         from six.moves import http_client
 
         credentials = object()
-        host = 'HOST'
-        user_agent = 'USER_AGENT'
+        host = "HOST"
+        user_agent = "USER_AGENT"
 
         secure_authorized_channel_patch = mock.patch(
-            'google.auth.transport.grpc.secure_authorized_channel',
-            autospec=True)
+            "google.auth.transport.grpc.secure_authorized_channel", autospec=True
+        )
 
         with secure_authorized_channel_patch as secure_authorized_channel:
             result = self._call_fut(credentials, user_agent, host)
 
         self.assertIs(result, secure_authorized_channel.return_value)
 
-        expected_target = '%s:%d' % (host, http_client.HTTPS_PORT)
-        expected_options = (('grpc.primary_user_agent', user_agent),)
+        expected_target = "%s:%d" % (host, http_client.HTTPS_PORT)
+        expected_options = (("grpc.primary_user_agent", user_agent),)
 
         secure_authorized_channel.assert_called_once_with(
-            credentials, mock.ANY, expected_target, options=expected_options)
+            credentials, mock.ANY, expected_target, options=expected_options
+        )
 
     def test_extra_options(self):
         from six.moves import http_client
 
         credentials = object()
-        host = 'HOST'
-        user_agent = 'USER_AGENT'
-        extra_options = (('some', 'option'),)
+        host = "HOST"
+        user_agent = "USER_AGENT"
+        extra_options = (("some", "option"),)
 
         secure_authorized_channel_patch = mock.patch(
-            'google.auth.transport.grpc.secure_authorized_channel',
-            autospec=True)
+            "google.auth.transport.grpc.secure_authorized_channel", autospec=True
+        )
 
         with secure_authorized_channel_patch as secure_authorized_channel:
-            result = self._call_fut(credentials, user_agent, host,
-                                    extra_options)
+            result = self._call_fut(credentials, user_agent, host, extra_options)
 
         self.assertIs(result, secure_authorized_channel.return_value)
 
-        expected_target = '%s:%d' % (host, http_client.HTTPS_PORT)
-        expected_options = (
-            ('grpc.primary_user_agent', user_agent),
-            extra_options[0],
-        )
+        expected_target = "%s:%d" % (host, http_client.HTTPS_PORT)
+        expected_options = (("grpc.primary_user_agent", user_agent), extra_options[0])
 
         secure_authorized_channel.assert_called_once_with(
-            credentials, mock.ANY, expected_target, options=expected_options)
+            credentials, mock.ANY, expected_target, options=expected_options
+        )
 
 
 class Test_make_secure_stub(unittest.TestCase):
-
     def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import make_secure_stub
 
@@ -827,21 +867,18 @@ class Test_make_secure_stub(unittest.TestCase):
             return channel_obj
 
         credentials = object()
-        user_agent = 'you-sir-age-int'
-        host = 'localhost'
-        extra_options = {'extra_options': ()}
+        user_agent = "you-sir-age-int"
+        host = "localhost"
+        extra_options = {"extra_options": ()}
         with _Monkey(MUT, make_secure_channel=mock_channel):
-            stub = self._call_fut(credentials, user_agent,
-                                  stub_class, host)
+            stub = self._call_fut(credentials, user_agent, stub_class, host)
 
         self.assertIs(stub, result)
         self.assertEqual(channels, [channel_obj])
-        self.assertEqual(channel_args,
-                         [(credentials, user_agent, host), extra_options])
+        self.assertEqual(channel_args, [(credentials, user_agent, host), extra_options])
 
 
 class Test_make_insecure_stub(unittest.TestCase):
-
     def _call_fut(self, *args, **kwargs):
         from google.cloud._helpers import make_insecure_stub
 
@@ -856,7 +893,6 @@ class Test_make_insecure_stub(unittest.TestCase):
         CHANNEL = object()
 
         class _GRPCModule(object):
-
             def insecure_channel(self, *args):
                 self.insecure_channel_args = args
                 return CHANNEL
@@ -875,11 +911,11 @@ class Test_make_insecure_stub(unittest.TestCase):
         self.assertEqual(grpc_mod.insecure_channel_args, (target,))
 
     def test_with_port_argument(self):
-        host = 'HOST'
+        host = "HOST"
         port = 1025
-        target = '%s:%d' % (host, port)
+        target = "%s:%d" % (host, port)
         self._helper(target, host, port=port)
 
     def test_without_port_argument(self):
-        host = 'HOST:1114'
+        host = "HOST:1114"
         self._helper(host, host)
